(funding)=
# Funding acknowledgments

Members of the lead development team acknowledge funding from:
- SNSF grant no. 184634, a MeteoSwiss [GCOS](https://gcos.wmo.int/en/home) project on elevation data analysis for glaciology,
- NASA award 80NSSC22K1094, an [STV](https://science.nasa.gov/earth-science/decadal-surveys/decadal-stv/) project on the fusion of elevation data,
- NASA award 80NSSC23K0192, an [ICESat-2](https://icesat-2.gsfc.nasa.gov/) project on the processing of elevation data in the cloud,
- CNES (French Space Agency) award on merging [demcompare](https://github.com/CNES/demcompare) and GeoUtils/xDEM while further developing related 3D tools.


::::{grid}
:reverse:

:::{grid-item}
:columns: 4
:child-align: center

```{image} ./_static/nasa_logo.svg
    :width: 200px
    :class: dark-light
```

:::

:::{grid-item}
:columns: 4
:child-align: center

```{image} ./_static/snsf_logo.svg
    :width: 220px
    :class: only-light
```

```{image} ./_static/snsf_logo_dark.svg
    :width: 220px
    :class: only-dark
```

:::

:::{grid-item}
:columns: 4
:child-align: center

```{image} ./_static/cnes_logo.svg
    :width: 200px
    :class: only-light
```

```{image} ./_static/cnes_logo_dark.svg
    :width: 200px
    :class: only-dark
```

:::


::::
